
function [x,P] = RungeKuttaKF(x,P)
global rho dt
    % Fourth order Runge Kutta integration for the falling body system.
    dx1(1,1) = x(2);
    dx1(2,1) = exp(-rho*x(1)) * x(2)^2 * x(3);
    dx1(3,1) = 0;
    dx1 = dx1 * dt;
    xtemp = x + dx1 / 2;
    F = [0 1 0; -rho*exp(-rho*x(1)) * x(2)^2 * x(3) ...
                exp(-rho*x(1)) * x(2)*2* x(3) ...
                exp(-rho*x(1)) * x(2)^2; ...
                 0 0 0];
            Pdot1 = (F * P + P * F')* dt;
            Ptemp = P + Pdot1/2 ;

    dx2(1,1) = xtemp(2);
    dx2(2,1) = exp(-rho*xtemp(1)) * xtemp(2)^2 * xtemp(3);
    dx2(3,1) = 0;
    dx2 = dx2 * dt;
    xtemp = x + dx2 / 2;
    F = [0 1 0; -rho*exp(-rho*xtemp(1)) * xtemp(2)^2 * xtemp(3) ...
                exp(-rho*xtemp(1)) * xtemp(2)*2* xtemp(3) ...
                exp(-rho*xtemp(1)) * xtemp(2)^2; ...
                 0 0 0];
            Pdot2 = (F * Ptemp + Ptemp * F') * dt;
            Ptemp = P + Pdot2/2;
    
    dx3(1,1) = xtemp(2);
    dx3(2,1) = exp(-rho*xtemp(1)) * xtemp(2)^2 * xtemp(3);
    dx3(3,1) = 0;
    dx3 = dx3 * dt;
    xtemp = x + dx3;
    F = [0 1 0; -rho*exp(-rho*xtemp(1)) * xtemp(2)^2 * xtemp(3) ...
                exp(-rho*xtemp(1)) * xtemp(2)*2* xtemp(3) ...
                exp(-rho*xtemp(1)) * xtemp(2)^2; ...
                 0 0 0];
            Pdot3 = (F * Ptemp + Ptemp * F')* dt;
            Ptemp = P + Pdot3 ;
            
    dx4(1,1) = xtemp(2);
    dx4(2,1) = exp(-rho*xtemp(1)) * xtemp(2)^2 * xtemp(3);
    dx4(3,1) = 0;
    dx4 = dx4 * dt;
    F = [0 1 0; -rho*exp(-rho*xtemp(1)) * xtemp(2)^2 * xtemp(3) ...
                exp(-rho*xtemp(1)) * xtemp(2)*2* xtemp(3) ...
                exp(-rho*xtemp(1)) * xtemp(2)^2; ...
                 0 0 0];
            Pdot4 = (F * Ptemp + Ptemp * F')* dt;
            
x = x + (dx1 + 2 * dx2 + 2 * dx3 + dx4) / 6;
P = P + (Pdot1 + 2 * Pdot2 + 2 * Pdot3 + Pdot4) / 6;

